@@ -1,5 +1,7 @@
-use crate::DataAfter;
-use crate::DataBefore;
+use crate::DateAfter;
+use crate::DateBefore;
+use crate::Keyword;
+use crate::Proxy;
 use crate::Size;
 use crate::Tag;
 use crate::R18;
@@ -12,7 +14,7 @@ impl Argument for Option<R18> {
     fn argument(&self, url: &mut String) {
         if let Some(r) = self {
             let argument = match r {
-                R18::NonR18 => "&r18=0",
+                R18::NonR18 => return, // default behavior
                 R18::R18 => "&r18=1",
                 R18::Mixin => "&r18=2",
             };
@@ -41,9 +43,9 @@ impl Argument for Option<Vec<u32>> {
     }
 }
 
-impl Argument for Option<String> {
+impl Argument for Keyword {
     fn argument(&self, url: &mut String) {
-        if let Some(key) = self {
+        if let Keyword(Some(key)) = self {
             let argument = format!("&keyword={}", key);
             url.push_str(&argument);
         }
@@ -71,3 +73,39 @@ impl Argument for Size {
         }
     }
 }
+
+impl Argument for Proxy {
+    fn argument(&self, url: &mut String) {
+        if let Proxy(Some(ref proxy)) = self {
+            let argument = format!("&proxy={}", proxy);
+            url.push_str(&argument);
+        }
+    }
+}
+
+impl Argument for DateAfter {
+    fn argument(&self, url: &mut String) {
+        if let DateAfter(Some(date)) = self {
+            let argument = format!("&dataAfter={}", date);
+            url.push_str(&argument);
+        }
+    }
+}
+
+impl Argument for DateBefore {
+    fn argument(&self, url: &mut String) {
+        if let DateBefore(Some(date)) = self {
+            let argument = format!("&dataBefore={}", date);
+            url.push_str(&argument);
+        }
+    }
+}
+
+impl Argument for Option<bool> {
+    fn argument(&self, url: &mut String) {
+        if let Some(dsc) = self {
+            let argument = format!("&dsc={:?}", dsc);
+            url.push_str(&argument);
+        }
+    }
+}
